==> odoo_19.1a1.20251209.zip: odoo-19.1a1.post20251209/odoo/addons/hr_attendance/static/src/components/new_employee_dialog/new_employee_dialog.js <==
import { Component, useState } from "@odoo/owl";
import { _t } from "@web/core/l10n/translation";
import { useService } from "@web/core/utils/hooks";
import { rpc } from "@web/core/network/rpc";
import { Dialog } from "@web/core/dialog/dialog";
import { Many2One } from "./many2one/many2one";

export class NewEmployeeDialog extends Component {
    static components = { Dialog, Many2One };
    static template = "hr_attendance.NewEmployeeDialog";
    static props = {
        title: { type: String, optional: true },
        footer: { type: Boolean, optional: true },
        token: { type: String },
    }
    static defaultProps = {
        title: _t("Set-up"),
        footer: false,
    };
    setup() {
        this.dialogService = useService("dialog");
        this.notification = useService("notification");
        this.state = useState({
            employeeName: "",
            badgeId: "",
            value: null,
            searchName: "",
            employeeHasBadge: false,
        });
    }

    onSelectEmployee(emp) {
        this.state.searchName = emp?.name ?? "";
        this.state.badgeId = "";
        if( this.state.searchName == ""){
            this.state.value = null;
        }
        else{
            this.state.value = emp;
            this.state.employeeHasBadge = false;
        }
    }

    async onCreate() {
        if (!this.state.employeeName || this.state.employeeName.trim() === "") {
            this.notification.add(_t("Employee name is required."), {
                title: _t("Validation Error"),
                type: "warning",
            });
            return;
        }
        try {
            const is_created = await rpc('/hr_attendance/create_employee', {
                name: this.state.employeeName,
                token: this.props.token
            });
            if (is_created) {
                this.notification.add(_t("Employee created successfully!"), { type: "success",});
                this.props.close();
            } else {
                this.notification.add(_t("Failed to create employee."), {
                    type: "danger",
                });
            }
        } catch (error) {
            this.notification.add(_t("Error creating employee: ") + error.message, {
                    type: "danger",
                });
        }
    }

    async onSetBadge() {
        const badge = this.state.badgeId?.trim();
        if (!this.state.value || !badge) {
            this.notification.add(_t("Please select an employee and enter a badge number."), {
                title: _t("Missing Data"),
                type: "warning",
            });
            return;
        }
        const employeeId = parseInt(this.state.value.id);
        const data = await rpc('/hr_attendance/set_badge', {
            employee_id: employeeId,
            badge: badge,
            token: this.props.token
        });
        if (data?.status === "success") {
            this.notification.add(_t("Badge assigned successfully!"), {
                type: "success",
            });
            this.state.employeeHasBadge = true;
        } else {
            this.notification.add( _t("Error: ") + _t(data?.message),{
                type: "danger",
            });
        }
    }
}

==> odoo_19.3a1.20260226.zip: odoo-19.3a1.post20260226/odoo/addons/hr_attendance/static/src/components/new_employee_dialog/new_employee_dialog.js <==
import { useState } from "@web/owl2/utils";
import { Component } from "@odoo/owl";
import { _t } from "@web/core/l10n/translation";
import { useService } from "@web/core/utils/hooks";
import { rpc } from "@web/core/network/rpc";
import { Dialog } from "@web/core/dialog/dialog";
import { Many2One } from "./many2one/many2one";

export class NewEmployeeDialog extends Component {
    static components = { Dialog, Many2One };
    static template = "hr_attendance.NewEmployeeDialog";
    static props = {
        title: { type: String, optional: true },
        footer: { type: Boolean, optional: true },
        token: { type: String },
    }
    static defaultProps = {
        title: _t("Set-up"),
        footer: false,
    };
    setup() {
        this.dialogService = useService("dialog");
        this.notification = useService("notification");
        this.state = useState({
            employeeName: "",
            badgeId: "",
            value: null,
            searchName: "",
            employeeHasBadge: false,
        });
    }

    onSelectEmployee(emp) {
        this.state.searchName = emp?.name ?? "";
        this.state.badgeId = "";
        if( this.state.searchName == ""){
            this.state.value = null;
        }
        else{
            this.state.value = emp;
            this.state.employeeHasBadge = false;
        }
    }

    async onCreate() {
        if (!this.state.employeeName || this.state.employeeName.trim() === "") {
            this.notification.add(_t("Employee name is required."), {
                title: _t("Validation Error"),
                type: "warning",
            });
            return;
        }
        try {
            const is_created = await rpc('/hr_attendance/create_employee', {
                name: this.state.employeeName,
                token: this.props.token
            });
            if (is_created) {
                this.notification.add(_t("Employee created successfully!"), { type: "success",});
                this.props.close();
            } else {
                this.notification.add(_t("Failed to create employee."), {
                    type: "danger",
                });
            }
        } catch (error) {
            this.notification.add(_t("Error creating employee: ") + error.message, {
                    type: "danger",
                });
        }
    }

    async onSetBadge() {
        const badge = this.state.badgeId?.trim();
        if (!this.state.value || !badge) {
            this.notification.add(_t("Please select an employee and enter a badge number."), {
                title: _t("Missing Data"),
                type: "warning",
            });
            return;
        }
        const employeeId = parseInt(this.state.value.id);
        const data = await rpc('/hr_attendance/set_badge', {
            employee_id: employeeId,
            badge: badge,
            token: this.props.token
        });
        if (data?.status === "success") {
            this.notification.add(_t("Badge assigned successfully!"), {
                type: "success",
            });
            this.state.employeeHasBadge = true;
        } else {
            this.notification.add( _t("Error: ") + _t(data?.message),{
                type: "danger",
            });
        }
    }
}
